
' PLEASE NOTE: RUNNING THE MODELS WITH THE PROVIDED PACEHOLDER DATA WILL PRODUCE DIFFERENT RESULTS THAN REPORTED IN THE PAPER DUE TO THIS SUBSTITUTION OF GASC TENDER DATA.

' PLEASE SEE README.TXT FILE FOR DETAILS

' Import the data 

import YOUR WORKING DIRECTORY HERE\data.csv ftype=ascii rectype=crlf skip=0 fieldtype=delimited delim=comma colhead=1 eoltype=pad badfield=NA @freq M 2011M07 @smpl @all

' Transform data to natural logarithm 
genr log_arg = log(arg)
genr log_aus = log(aus)
genr log_can = log(can)
genr log_fra = log(fra)
genr log_kaz = log(kaz)
genr log_rus = log(rus)
genr log_ukr = log(ukr)
genr log_usa = log(usa)

' Define US HRW export prices as placeholder for GASC tender prices 
genr log_gasc_placeholder = log(hrw)

' Estimation of unrestricted VECM (Main Model), normalized to GASC tender prices
var main_vecm 1 3 log_rus log_fra log_usa log_gasc_placeholder 
main_vecm.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1
main_vecm.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

' Restricting all three beta coefficients to zero to test LOP 
var vecm_lop_full 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_lop_full.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(1,1)=1, b(2,2)=1, b(3,3)=1
vecm_lop_full.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

''''''''''''''''''' Testing the LOP on individual beta coefficients '''''''''''''''''''
' LOP holding between Rusian and GASC prices 
var vecm_lop_rus 1 3 log_rus log_fra log_usa log_gasc_placeholder
vecm_lop_rus.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(1,1)=1
vecm_lop_rus.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

' LOP holding between French and GASC prices 
var vecm_lop_fra 1 3 log_rus log_fra log_usa log_gasc_placeholder
vecm_lop_fra.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(2,2)=1
vecm_lop_fra.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

' LOP holding between US and GASC prices 
var vecm_lop_usa 1 3 log_rus log_fra log_usa log_gasc_placeholder
vecm_lop_usa.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(3,3)=1
vecm_lop_usa.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

''''''''''''''''''' Testing equality of implied and observed freight costs '''''''''''''''''''
' Equality of Implied and observed freight costs for Russia
var vecm_freight_rus 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_freight_rus.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(1,1)=1, b(2,2)=1, b(3,3)=1, b(1,5)= (13.5/237.9)
vecm_freight_rus.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 


' Equality of Implied and observed freight costs for France
var vecm_freight_fra 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_freight_fra.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(1,1)=1, b(2,2)=1, b(3,3)=1, b(2,5)= (15.5/236.9)
vecm_freight_fra.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

 ' Equality of Implied and observed freight costs for USA
var vecm_freight_usa 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_freight_usa.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, b(1,1)=1, b(2,2)=1, b(3,3)=1, b(3,5)= (29/227.1)
vecm_freight_usa.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

''''''''''''''''''' Weak exogeneity tests '''''''''''''''''''
' of Russian prices 
var vecm_exog_rus 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_exog_rus.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, a(1,1)=0, a(1,2)=0, a(1,3)=0
vecm_exog_rus.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

' of French prices
var vecm_exog_fra 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_exog_fra.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, a(2,1)=0, a(2,2)=0, a(2,3)=0
vecm_exog_fra.ec(b,3, restrict) 1 3 log_rus log_fra log_usa log_gasc_placeholder 

' of US prices
var vecm_exog_usa 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_exog_usa.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, a(3,1)=0, a(3,2)=0, a(3,3)=0
vecm_exog_usa.ec(b,3, restrict) 1 3  log_rus log_fra log_usa log_gasc_placeholder

' of GASC prices
var vecm_exog_gasc 1 3 log_rus log_fra log_usa log_gasc_placeholder 
vecm_exog_gasc.append(coint) b(2,1)=0, b(3,1)=0, b(1,2)=0, b(3,2)=0, b(1,3)=0, b(2,3)=0, b(1,4)=-1, b(2,4)=-1, b(3,4)=-1, a(4,1)=0, a(4,2)=0, a(4,3)=0
vecm_exog_gasc.ec(b,3, restrict) 1 3  log_rus log_fra log_usa log_gasc_placeholder 

' Diagnostic tests
main_vecm.qstats(12)
main_vecm.white

''''''''''''''''''' Comparison to bivariate models '''''''''''''''''''
' GASC-Russia
var bi_vecm_rus 1 3 log_rus log_gasc_placeholder
bi_vecm_rus.append(coint) b(1,1)=-1
bi_vecm_rus.ec(b,1, restrict) 1 3 log_gasc_placeholder log_rus

var bi_vecm_rus_restrict 1 3 log_rus log_gasc_placeholder
bi_vecm_rus_restrict.append(coint) b(1,1)=-1, b(1,2)=0.883
bi_vecm_rus_restrict.ec(b,1, restrict) 1 3 log_gasc_placeholder log_rus

' GASC-France
var bi_vecm_fra 1 3 log_fra log_gasc_placeholder
bi_vecm_fra.append(coint) b(1,1)=-1
bi_vecm_fra.ec(b,1, restrict) 1 3 log_gasc_placeholder log_fra

var bi_vecm_fra_restrict 1 3 log_fra log_gasc_placeholder
bi_vecm_fra_restrict.append(coint) b(1,1)=-1, b(1,2)=0.885
bi_vecm_fra_restrict.ec(b,1, restrict) 1 3 log_gasc_placeholder log_fra

' GASC-USA
var bi_vecm_usa 1 3 log_usa log_gasc_placeholder
bi_vecm_usa.append(coint) b(1,1)=-1
bi_vecm_usa.ec(b,1, restrict) 1 3 log_gasc_placeholder log_usa

var bi_vecm_usa_restrict 1 3 log_usa log_gasc_placeholder
bi_vecm_usa_restrict.append(coint) b(1,1)=-1, b(1,2)=0.914
bi_vecm_usa_restrict.ec(b,1, restrict) 1 3 log_gasc_placeholder log_usa

''''''''''''''''''' Generalized Impulse Response Functions '''''''''''''''''''
' Please note: EViews reports the Impulse response graphs by grouping together the responses of one market to shocks originating in the other markets in one graph. In our paper, we group together differently, namely by presenting the different responses of the considered markets to a shock originating in one market. This is more in line with the literature convention reporting IRF results. 

' To give an example, the "GASC shocked" panel of Figure 3 in the paper groups the four black lines reported in the four graphs that EViews reports with the following command in one figure.

' Graph Generalized Impulse Response Functions
main_vecm.impulse(20, g, imp=gen)

'''''''''''''''''''''' APPENDIX '''''''''''''''''''''''''''

' Unit root and stationarity tests
' ADF test on log price levels with constant
log_arg.uroot(maxlag=12)
log_aus.uroot(maxlag=12)
log_can.uroot(maxlag=12)
log_fra.uroot(maxlag=12)
log_gasc_placeholder.uroot(maxlag=12)
log_kaz.uroot(maxlag=12)
log_rus.uroot(maxlag=12)
log_ukr.uroot(maxlag=12)
log_usa.uroot(maxlag=12)

' ADF test on log price levels with constant and trend
log_arg.uroot(exog=trend, maxlag=12)
log_aus.uroot(exog=trend, maxlag=12)
log_can.uroot(exog=trend, maxlag=12)
log_fra.uroot(exog=trend, maxlag=12)
log_gasc_placeholder.uroot(exog=trend, maxlag=12)
log_kaz.uroot(exog=trend, maxlag=12)
log_rus.uroot(exog=trend, maxlag=12)
log_ukr.uroot(exog=trend, maxlag=12)
log_usa.uroot(exog=trend, maxlag=12)

' ADF test on log prices in first differences
log_arg.uroot(exog=none,dif=1, maxlag=12)
log_aus.uroot(exog=none,dif=1, maxlag=12)
log_can.uroot(exog=none,dif=1, maxlag=12)
log_fra.uroot(exog=none,dif=1, maxlag=12)
log_gasc_placeholder.uroot(exog=none,dif=1, maxlag=12)
log_kaz.uroot(exog=none,dif=1, maxlag=12)
log_rus.uroot(exog=none,dif=1, maxlag=12)
log_ukr.uroot(exog=none,dif=1, maxlag=12)
log_usa.uroot(exog=none,dif=1, maxlag=12)

' KPSS test on log price levels with constant
log_gasc_placeholder.uroot(kpss)
log_rus.uroot(kpss)
log_fra.uroot(kpss)
log_usa.uroot(kpss)
log_ukr.uroot(kpss)
log_arg.uroot(kpss)
log_kaz.uroot(kpss)
log_can.uroot(kpss)
log_aus.uroot(kpss)

' KPSS test on log price levels with constant and trend
log_gasc_placeholder.uroot(exog=trend, kpss)
log_rus.uroot(exog=trend, kpss)
log_fra.uroot(exog=trend, kpss)
log_usa.uroot(exog=trend, kpss)
log_ukr.uroot(exog=trend, kpss)
log_arg.uroot(exog=trend, kpss)
log_kaz.uroot(exog=trend, kpss)
log_can.uroot(exog=trend, kpss)
log_aus.uroot(exog=trend, kpss)

' KPSS test on log prices in first differences
log_gasc_placeholder.uroot(dif=1, kpss)
log_rus.uroot(dif=1, kpss)
log_fra.uroot(dif=1, kpss)
log_usa.uroot(dif=1, kpss)
log_ukr.uroot(dif=1, kpss)
log_arg.uroot(dif=1, kpss)
log_kaz.uroot(dif=1, kpss)
log_can.uroot(dif=1, kpss)
log_aus.uroot(dif=1, kpss)


